import { Button } from "@/components/ui/button";
import { motion } from "framer-motion";

// Location card interface
interface LocationCardProps {
  city: string;
  country: string;
  time: string;
  address: string;
  color: string;
  delay: number;
}

// Location card component
const LocationCard = ({ city, country, time, address, color, delay }: LocationCardProps) => (
  <motion.div 
    className="relative rounded-2xl bg-white p-6 shadow-lg flex flex-col justify-between h-[200px] md:h-[230px] overflow-hidden"
    initial={{ opacity: 0, y: 30 }}
    whileInView={{ opacity: 1, y: 0 }}
    transition={{ duration: 0.7, delay: delay }}
    viewport={{ once: true }}
    whileHover={{ y: -5, transition: { duration: 0.3 } }}
  >
    <div>
      <h3 className="font-heading text-xl font-bold">
        {city}, <br />{country}
      </h3>
      <p className="text-xl font-bold mt-2">{time}</p>
    </div>
    <p className="text-gray-600 text-sm">{address}</p>
    <div className="absolute -right-4 -bottom-4 w-20 h-20 rounded-tl-3xl" style={{ backgroundColor: color }} />
  </motion.div>
);

// Stats item component
const StatItem = ({ value, label, delay }: { value: string; label: string; delay: number }) => (
  <motion.div
    className="p-6 bg-white rounded-2xl shadow-md"
    initial={{ opacity: 0, scale: 0.9 }}
    whileInView={{ opacity: 1, scale: 1 }}
    transition={{ duration: 0.5, delay }}
    viewport={{ once: true }}
  >
    <p className="font-heading font-bold text-4xl text-blue-600">{value}</p>
    <p className="text-gray-700 font-medium">{label}</p>
  </motion.div>
);

export default function About() {
  // Stats data
  const stats = [
    { value: "120+", label: "Happy Clients" },
    { value: "350+", label: "Projects Completed" },
    { value: "24", label: "Design Awards" },
    { value: "15+", label: "Years Experience" }
  ];

  // Location data
  const locations = [
    { 
      city: "Bangkok", 
      country: "Thailand", 
      time: "06:05:07 PM", 
      address: "Vibhavadi Rangsit 4 Alley, Din Daeng 10400",
      color: "#17CAD9"
    },
    { 
      city: "Barcelona", 
      country: "Spain", 
      time: "01:05:07 PM", 
      address: "Carrer de Pallars 193, 08005",
      color: "#FF5470"
    },
    { 
      city: "Hong Kong", 
      country: "China", 
      time: "07:05:07 PM", 
      address: "88 Queens Road, Central District",
      color: "#FFC043"
    }
  ];

  return (
    <section id="about" className="relative">
      {/* Color block header */}
      <div className="bg-blue-600 py-28 md:py-36 relative overflow-hidden">
        <motion.div 
          className="absolute top-0 right-0 w-full h-8 bg-yellow-300"
          initial={{ opacity: 0 }}
          whileInView={{ opacity: 1 }}
          transition={{ duration: 0.5 }}
          viewport={{ once: true }}
        />
        
        <div className="container mx-auto px-6 relative z-10">
          <motion.div 
            className="max-w-3xl"
            initial={{ opacity: 0, y: 30 }}
            whileInView={{ opacity: 1, y: 0 }}
            transition={{ duration: 0.7 }}
            viewport={{ once: true }}
          >
            <motion.span 
              className="inline-block text-white/90 font-bold px-4 py-2 border border-white/20 rounded-full backdrop-blur-sm mb-6"
              initial={{ opacity: 0, x: -20 }}
              whileInView={{ opacity: 1, x: 0 }}
              transition={{ duration: 0.5, delay: 0.3 }}
              viewport={{ once: true }}
            >
              About Us
            </motion.span>
            <motion.h2 
              className="font-heading text-4xl md:text-5xl lg:text-6xl font-bold text-white mb-8"
              initial={{ opacity: 0, y: 20 }}
              whileInView={{ opacity: 1, y: 0 }}
              transition={{ duration: 0.5, delay: 0.4 }}
              viewport={{ once: true }}
            >
              Glimpses of <br />Brand Success
            </motion.h2>
            <motion.p 
              className="text-white/90 text-lg md:text-xl"
              initial={{ opacity: 0, y: 20 }}
              whileInView={{ opacity: 1, y: 0 }}
              transition={{ duration: 0.5, delay: 0.5 }}
              viewport={{ once: true }}
            >
              At Burlatech, we blend strategic thinking with creative execution to deliver designs that stand out and perform. Our multidisciplinary approach ensures every project is approached holistically.
            </motion.p>
          </motion.div>
        </div>
        
        {/* Animated shapes */}
        <motion.div 
          className="absolute bottom-0 right-0 w-96 h-96 bg-blue-500/50 rounded-full -mb-48 -mr-48 blur-3xl"
          initial={{ opacity: 0 }}
          whileInView={{ opacity: 1 }}
          transition={{ duration: 1, delay: 0.3 }}
          viewport={{ once: true }}
        />
        <motion.div 
          className="absolute top-0 left-0 w-96 h-96 bg-blue-700/50 rounded-full -mt-48 -ml-48 blur-3xl"
          initial={{ opacity: 0 }}
          whileInView={{ opacity: 1 }}
          transition={{ duration: 1, delay: 0.5 }}
          viewport={{ once: true }}
        />
      </div>
      
      {/* Portfolio section */}
      <div className="py-20 bg-gray-50">
        <div className="container mx-auto px-6">
          <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-4 gap-6 md:gap-8">
            {stats.map((stat, index) => (
              <StatItem 
                key={stat.label}
                value={stat.value}
                label={stat.label}
                delay={index * 0.1 + 0.2}
              />
            ))}
          </div>
          
          <motion.div 
            className="mt-32"
            initial={{ opacity: 0 }}
            whileInView={{ opacity: 1 }}
            transition={{ duration: 1 }}
            viewport={{ once: true }}
          >
            <div className="flex flex-col md:flex-row justify-between items-start md:items-end mb-16">
              <motion.h2 
                className="font-heading text-3xl md:text-4xl font-bold"
                initial={{ opacity: 0, y: 20 }}
                whileInView={{ opacity: 1, y: 0 }}
                transition={{ duration: 0.5 }}
                viewport={{ once: true }}
              >
                Our offices
              </motion.h2>
              <motion.div
                className="mt-6 md:mt-0"
                initial={{ opacity: 0, y: 20 }}
                whileInView={{ opacity: 1, y: 0 }}
                transition={{ duration: 0.5, delay: 0.2 }}
                viewport={{ once: true }}
              >
                <h3 className="font-heading text-2xl md:text-3xl font-bold mb-4">
                  You can find us in <span className="text-blue-600">Bangkok</span>, <br />
                  <span className="text-blue-600">Barcelona</span> & <span className="text-blue-600">Hong Kong</span>
                </h3>
                <Button 
                  className="bg-black text-white rounded-full hover:bg-black/90"
                  size="lg"
                  asChild
                >
                  <a href="#contact">Say Hi!</a>
                </Button>
              </motion.div>
            </div>
            
            {/* Location cards */}
            <div className="grid grid-cols-1 md:grid-cols-3 gap-6">
              {locations.map((location, index) => (
                <LocationCard 
                  key={location.city}
                  city={location.city}
                  country={location.country}
                  time={location.time}
                  address={location.address}
                  color={location.color}
                  delay={index * 0.1 + 0.3}
                />
              ))}
            </div>
          </motion.div>
        </div>
      </div>
      
      {/* Yellow-blue transition at the bottom */}
      <div className="w-full h-8 bg-yellow-300"></div>
      <div className="w-full h-8 bg-blue-600"></div>
    </section>
  );
}
