import { useState, useRef } from "react";
import { 
  MapPin, 
  Mail, 
  Phone, 
  Linkedin, 
  Twitter, 
  Instagram, 
  Dribbble,
  ArrowRight 
} from "lucide-react";
import { zodResolver } from "@hookform/resolvers/zod";
import { useForm } from "react-hook-form";
import { z } from "zod";
import { useToast } from "@/hooks/use-toast";
import { apiRequest } from "@/lib/queryClient";
import { Button } from "@/components/ui/button";
import {
  Form,
  FormControl,
  FormField,
  FormItem,
  FormLabel,
  FormMessage,
} from "@/components/ui/form";
import { Input } from "@/components/ui/input";
import { Textarea } from "@/components/ui/textarea";
import {
  Select,
  SelectContent,
  SelectItem,
  SelectTrigger,
  SelectValue,
} from "@/components/ui/select";
import { motion, useInView } from "framer-motion";

// Social icon component
const SocialIcon = ({ icon, href, color }: { icon: React.ReactNode, href: string, color: string }) => (
  <motion.a
    href={href}
    className="w-12 h-12 rounded-full flex items-center justify-center text-white transition-all duration-300"
    style={{ backgroundColor: color }}
    target="_blank"
    rel="noopener noreferrer"
    whileHover={{ scale: 1.1 }}
    whileTap={{ scale: 0.95 }}
  >
    {icon}
  </motion.a>
);

// Form schema
const formSchema = z.object({
  name: z.string().min(2, "Name must be at least 2 characters."),
  email: z.string().email("Please enter a valid email address."),
  service: z.string().min(1, "Please select a service."),
  message: z.string().min(10, "Message must be at least 10 characters.")
});

type FormValues = z.infer<typeof formSchema>;

export default function Contact() {
  const [isSubmitting, setIsSubmitting] = useState(false);
  const { toast } = useToast();
  const formRef = useRef<HTMLDivElement>(null);
  const isInView = useInView(formRef, { once: true, amount: 0.2 });
  
  // Form definition
  const form = useForm<FormValues>({
    resolver: zodResolver(formSchema),
    defaultValues: {
      name: "",
      email: "",
      service: "",
      message: ""
    }
  });

  // Contact form submission handler
  const onSubmit = async (data: FormValues) => {
    setIsSubmitting(true);
    
    try {
      await apiRequest("POST", "/api/contact", data);
      
      toast({
        title: "Message sent!",
        description: "We'll get back to you as soon as possible.",
        variant: "default"
      });
      
      form.reset();
    } catch (error) {
      toast({
        title: "Something went wrong.",
        description: "Your message couldn't be sent. Please try again.",
        variant: "destructive"
      });
    } finally {
      setIsSubmitting(false);
    }
  };

  // Social media links
  const socialLinks = [
    { icon: <Linkedin className="h-5 w-5" />, href: "#", color: "#0077B5" },
    { icon: <Twitter className="h-5 w-5" />, href: "#", color: "#1DA1F2" },
    { icon: <Instagram className="h-5 w-5" />, href: "#", color: "#E4405F" },
    { icon: <Dribbble className="h-5 w-5" />, href: "#", color: "#EA4C89" }
  ];
  
  // Service options
  const serviceOptions = [
    "Branding Design",
    "Digital Design",
    "Product Design",
    "Packaging Design",
    "Strategy & Innovation",
    "Communication Services"
  ];

  return (
    <section id="contact" className="py-20 relative overflow-hidden">
      {/* Background elements */}
      <motion.div 
        className="absolute right-0 bottom-0 w-1/2 h-full bg-gradient-to-l from-yellow-300/10 to-transparent hidden lg:block"
        initial={{ opacity: 0 }}
        whileInView={{ opacity: 1 }}
        transition={{ duration: 1 }}
        viewport={{ once: true }}
      />
      <motion.div 
        className="absolute top-0 left-0 w-full h-16 bg-blue-600"
        initial={{ opacity: 0 }}
        whileInView={{ opacity: 1 }}
        transition={{ duration: 0.5 }}
        viewport={{ once: true }}
      />
      
      <div className="container mx-auto px-6 relative z-10">
        <motion.div 
          className="mb-16"
          initial={{ opacity: 0, y: 30 }}
          whileInView={{ opacity: 1, y: 0 }}
          transition={{ duration: 0.7 }}
          viewport={{ once: true }}
        >
          <div className="flex flex-col md:flex-row justify-between md:items-end">
            <div>
              <motion.span 
                className="text-blue-600 font-bold inline-block mb-2 text-lg"
                initial={{ opacity: 0, x: -20 }}
                whileInView={{ opacity: 1, x: 0 }}
                transition={{ duration: 0.5 }}
                viewport={{ once: true }}
              >
                Get In Touch
              </motion.span>
              <motion.h2 
                className="font-heading text-4xl md:text-5xl font-bold mb-2"
                initial={{ opacity: 0, y: 20 }}
                whileInView={{ opacity: 1, y: 0 }}
                transition={{ duration: 0.5, delay: 0.1 }}
                viewport={{ once: true }}
              >
                Let's Create Something<br />Amazing Together
              </motion.h2>
            </div>
            <motion.p 
              className="text-lg text-gray-600 md:text-xl md:max-w-md mt-4 md:mt-0"
              initial={{ opacity: 0, y: 20 }}
              whileInView={{ opacity: 1, y: 0 }}
              transition={{ duration: 0.5, delay: 0.2 }}
              viewport={{ once: true }}
            >
              Ready to elevate your brand? We're excited to hear about your project and explore how we can bring your vision to life.
            </motion.p>
          </div>
        </motion.div>
        
        <div className="grid grid-cols-1 lg:grid-cols-2 gap-16">
          {/* Contact information */}
          <motion.div
            initial={{ opacity: 0, y: 50 }}
            whileInView={{ opacity: 1, y: 0 }}
            transition={{ duration: 0.7 }}
            viewport={{ once: true }}
          >
            <div className="bg-blue-600 text-white p-10 rounded-2xl relative overflow-hidden">
              <div className="relative z-10">
                <h3 className="font-heading text-2xl font-bold mb-8">Contact Information</h3>
                
                <div className="space-y-8 mb-12">
                  <div className="flex items-start">
                    <div className="w-12 h-12 bg-white/10 rounded-full flex items-center justify-center">
                      <MapPin className="h-5 w-5" />
                    </div>
                    <div className="ml-4">
                      <h4 className="font-bold mb-1">Our Headquarters</h4>
                      <p className="opacity-80">123 Design Avenue, Creative District<br />New York, NY 10001</p>
                    </div>
                  </div>
                  
                  <div className="flex items-start">
                    <div className="w-12 h-12 bg-white/10 rounded-full flex items-center justify-center">
                      <Mail className="h-5 w-5" />
                    </div>
                    <div className="ml-4">
                      <h4 className="font-bold mb-1">Email Us</h4>
                      <p className="opacity-80">hello@burlatech.com</p>
                    </div>
                  </div>
                  
                  <div className="flex items-start">
                    <div className="w-12 h-12 bg-white/10 rounded-full flex items-center justify-center">
                      <Phone className="h-5 w-5" />
                    </div>
                    <div className="ml-4">
                      <h4 className="font-bold mb-1">Call Us</h4>
                      <p className="opacity-80">+1 (555) 234-5678</p>
                    </div>
                  </div>
                </div>
                
                <h3 className="font-heading text-xl font-bold mb-5">Follow Us</h3>
                <div className="flex space-x-4">
                  {socialLinks.map((link, index) => (
                    <SocialIcon 
                      key={index}
                      icon={link.icon}
                      href={link.href}
                      color={link.color}
                    />
                  ))}
                </div>
              </div>
              
              {/* Decorative elements */}
              <div className="absolute bottom-0 right-0 w-40 h-40 bg-blue-700 rounded-tl-full -mb-10 -mr-10" />
              <div className="absolute top-0 left-0 w-20 h-20 bg-blue-700 rounded-br-full -mt-5 -ml-5" />
            </div>
          </motion.div>
          
          {/* Contact form */}
          <motion.div 
            ref={formRef}
            initial={{ opacity: 0, y: 50 }}
            animate={isInView ? { opacity: 1, y: 0 } : { opacity: 0, y: 50 }}
            transition={{ duration: 0.7, delay: 0.2 }}
          >
            <div className="bg-white p-10 rounded-2xl shadow-xl">
              <h3 className="font-heading text-2xl font-bold mb-8">Send Us a Message</h3>
              
              <Form {...form}>
                <form 
                  onSubmit={form.handleSubmit(onSubmit)} 
                  className="space-y-6"
                >
                  <div className="grid grid-cols-1 md:grid-cols-2 gap-6">
                    <FormField
                      control={form.control}
                      name="name"
                      render={({ field }) => (
                        <FormItem>
                          <FormLabel className="font-medium">Your Name</FormLabel>
                          <FormControl>
                            <Input 
                              placeholder="John Doe" 
                              {...field} 
                              className="px-4 py-3 rounded-lg border-gray-300 focus:border-blue-600 focus:ring-blue-600"
                            />
                          </FormControl>
                          <FormMessage />
                        </FormItem>
                      )}
                    />
                    
                    <FormField
                      control={form.control}
                      name="email"
                      render={({ field }) => (
                        <FormItem>
                          <FormLabel className="font-medium">Email Address</FormLabel>
                          <FormControl>
                            <Input 
                              placeholder="john@example.com" 
                              type="email" 
                              {...field} 
                              className="px-4 py-3 rounded-lg border-gray-300 focus:border-blue-600 focus:ring-blue-600"
                            />
                          </FormControl>
                          <FormMessage />
                        </FormItem>
                      )}
                    />
                  </div>
                  
                  <FormField
                    control={form.control}
                    name="service"
                    render={({ field }) => (
                      <FormItem>
                        <FormLabel className="font-medium">Service Needed</FormLabel>
                        <Select onValueChange={field.onChange} value={field.value}>
                          <FormControl>
                            <SelectTrigger className="px-4 py-3 rounded-lg border-gray-300 focus:border-blue-600 focus:ring-blue-600">
                              <SelectValue placeholder="Select a service" />
                            </SelectTrigger>
                          </FormControl>
                          <SelectContent>
                            {serviceOptions.map((service) => (
                              <SelectItem key={service} value={service}>
                                {service}
                              </SelectItem>
                            ))}
                          </SelectContent>
                        </Select>
                        <FormMessage />
                      </FormItem>
                    )}
                  />
                  
                  <FormField
                    control={form.control}
                    name="message"
                    render={({ field }) => (
                      <FormItem>
                        <FormLabel className="font-medium">Your Message</FormLabel>
                        <FormControl>
                          <Textarea 
                            placeholder="Tell us about your project..." 
                            rows={5} 
                            {...field} 
                            className="px-4 py-3 rounded-lg resize-none border-gray-300 focus:border-blue-600 focus:ring-blue-600"
                          />
                        </FormControl>
                        <FormMessage />
                      </FormItem>
                    )}
                  />
                  
                  <motion.div
                    whileHover={{ scale: 1.03 }}
                    whileTap={{ scale: 0.98 }}
                  >
                    <Button 
                      type="submit" 
                      className="w-full bg-blue-600 text-white hover:bg-blue-700 rounded-lg py-6 font-bold text-lg flex items-center justify-center"
                      disabled={isSubmitting}
                    >
                      {isSubmitting ? "Sending..." : (
                        <>
                          Send Message
                          <ArrowRight className="ml-2 h-5 w-5" />
                        </>
                      )}
                    </Button>
                  </motion.div>
                </form>
              </Form>
            </div>
          </motion.div>
        </div>
      </div>
    </section>
  );
}
