import { useState, useEffect } from 'react';
import { motion } from 'framer-motion';

export default function CustomCursor() {
  // In production, don't use the custom cursor to prevent performance issues
  if (process.env.NODE_ENV === 'production' || typeof window === 'undefined') {
    return null;
  }
  
  const [mousePosition, setMousePosition] = useState({ x: 0, y: 0 });
  const [cursorVariant, setCursorVariant] = useState('default');
  const [isMobile, setIsMobile] = useState(false);
  
  // Check if it's a mobile device to prevent cursor on mobile
  useEffect(() => {
    const checkMobile = () => {
      setIsMobile(window.innerWidth < 768);
    };
    
    checkMobile();
    window.addEventListener('resize', checkMobile);
    
    return () => {
      window.removeEventListener('resize', checkMobile);
    };
  }, []);

  // Track mouse position with throttling for better performance
  useEffect(() => {
    let lastCalled = 0;
    const throttleAmount = 10; // ms
    
    const handleMouseMove = (e: MouseEvent) => {
      const now = Date.now();
      if (now - lastCalled < throttleAmount) return;
      
      lastCalled = now;
      setMousePosition({ x: e.clientX, y: e.clientY });
    };

    window.addEventListener('mousemove', handleMouseMove);
    
    return () => {
      window.removeEventListener('mousemove', handleMouseMove);
    };
  }, []);

  // Set cursor variant based on what's being hovered
  useEffect(() => {
    const handleMouseOver = (e: MouseEvent) => {
      const target = e.target as HTMLElement;
      
      if (
        target.tagName === 'A' ||
        target.tagName === 'BUTTON' ||
        target.classList.contains('hover-lift') ||
        target.classList.contains('service-card')
      ) {
        setCursorVariant('hover');
      } else {
        setCursorVariant('default');
      }
    };

    window.addEventListener('mouseover', handleMouseOver);
    
    return () => {
      window.removeEventListener('mouseover', handleMouseOver);
    };
  }, []);

  // Cursor variants
  const variants = {
    default: {
      x: mousePosition.x - 12,
      y: mousePosition.y - 12,
      width: 24,
      height: 24,
      backgroundColor: 'rgba(37, 99, 235, 0.3)'
    },
    hover: {
      x: mousePosition.x - 24,
      y: mousePosition.y - 24,
      width: 48,
      height: 48,
      backgroundColor: 'rgba(254, 91, 52, 0.2)'
    }
  };

  // Don't render anything on mobile
  if (isMobile) {
    return null;
  }

  return (
    <motion.div
      className="fixed rounded-full pointer-events-none z-[9999] mix-blend-difference hidden md:block"
      variants={variants}
      animate={cursorVariant}
      transition={{ 
        type: 'spring', 
        stiffness: 500,
        damping: 28,
        mass: 0.5
      }}
    />
  );
}
