import { Link } from "wouter";
import { Linkedin, Twitter, Instagram, Dribbble, ArrowRight, Map, Mail, Phone } from "lucide-react";
import { Input } from "@/components/ui/input";
import { Button } from "@/components/ui/button";
import { motion } from "framer-motion";

// Footer link group interface
interface FooterLinkGroupProps {
  title: string;
  links: Array<{ label: string; href: string }>;
  delay: number;
}

// Footer link group component with animation
const FooterLinkGroup = ({ title, links, delay }: FooterLinkGroupProps) => (
  <motion.div
    initial={{ opacity: 0, y: 20 }}
    whileInView={{ opacity: 1, y: 0 }}
    transition={{ duration: 0.5, delay }}
    viewport={{ once: true }}
  >
    <h3 className="font-heading font-bold text-xl mb-6">{title}</h3>
    <ul className="space-y-3">
      {links.map((link, index) => (
        <motion.li 
          key={link.label}
          initial={{ opacity: 0, x: -10 }}
          whileInView={{ opacity: 1, x: 0 }}
          transition={{ duration: 0.3, delay: delay + (index * 0.05) }}
          viewport={{ once: true }}
        >
          <a 
            href={link.href} 
            className="hover:text-yellow-300 transition-colors duration-200 flex items-center group"
          >
            <ArrowRight className="h-4 w-0 mr-0 group-hover:w-4 group-hover:mr-2 transition-all duration-200 overflow-hidden" />
            {link.label}
          </a>
        </motion.li>
      ))}
    </ul>
  </motion.div>
);

// Social icon component
const SocialIcon = ({ icon, href, color }: { icon: React.ReactNode, href: string, color: string }) => (
  <motion.a
    href={href}
    className="w-10 h-10 rounded-full flex items-center justify-center text-white transition-transform duration-200"
    style={{ backgroundColor: color }}
    target="_blank"
    rel="noopener noreferrer"
    whileHover={{ scale: 1.1 }}
    whileTap={{ scale: 0.95 }}
  >
    {icon}
  </motion.a>
);

// Location item component
const LocationItem = ({ city, country, icon }: { city: string, country: string, icon: React.ReactNode }) => (
  <div className="flex items-center space-x-3">
    <div className="w-8 h-8 bg-white/10 rounded-full flex items-center justify-center">
      {icon}
    </div>
    <div>
      <p className="font-medium">{city}, {country}</p>
    </div>
  </div>
);

export default function Footer() {
  // Current year for copyright
  const currentYear = new Date().getFullYear();
  
  // Services links
  const servicesLinks = [
    { label: "Strategy & Innovation", href: "#services" },
    { label: "Branding Design", href: "#services" },
    { label: "Digital Design", href: "#services" },
    { label: "Product Design", href: "#services" },
    { label: "Packaging Design", href: "#services" }
  ];
  
  // Company links
  const companyLinks = [
    { label: "About Us", href: "#about" },
    { label: "Our Work", href: "#work" },
    { label: "Careers", href: "#" },
    { label: "Blog", href: "#" },
    { label: "Contact", href: "#contact" }
  ];
  
  // Social media links
  const socialLinks = [
    { icon: <Linkedin className="h-5 w-5" />, href: "#", color: "#0077B5" },
    { icon: <Twitter className="h-5 w-5" />, href: "#", color: "#1DA1F2" },
    { icon: <Instagram className="h-5 w-5" />, href: "#", color: "#E4405F" },
    { icon: <Dribbble className="h-5 w-5" />, href: "#", color: "#EA4C89" }
  ];
  
  // Locations
  const locations = [
    { city: "Bangkok", country: "Thailand", icon: <Map className="h-4 w-4" /> },
    { city: "Barcelona", country: "Spain", icon: <Map className="h-4 w-4" /> },
    { city: "Hong Kong", country: "China", icon: <Map className="h-4 w-4" /> },
  ];
  
  // Footer links
  const footerLinks = [
    { label: "Privacy Policy", href: "/privacy-policy" },
    { label: "Terms of Service", href: "/terms-of-service" },
    { label: "Cookies", href: "/cookies-policy" }
  ];

  return (
    <footer>
      {/* Upper footer with newsletter and colorful background */}
      <div className="bg-blue-600 py-20 text-white relative overflow-hidden">
        <div className="absolute top-0 left-0 w-full h-8 bg-yellow-300"></div>
        
        {/* Decorative elements */}
        <div className="absolute bottom-0 right-0 w-96 h-96 bg-blue-500/30 rounded-full -mb-48 -mr-48 blur-3xl"></div>
        <div className="absolute top-0 left-0 w-96 h-96 bg-blue-700/30 rounded-full -mt-48 -ml-48 blur-3xl"></div>
        
        <div className="container mx-auto px-6 relative">
          <div className="grid grid-cols-1 lg:grid-cols-2 gap-16 items-center">
            <motion.div
              initial={{ opacity: 0, y: 30 }}
              whileInView={{ opacity: 1, y: 0 }}
              transition={{ duration: 0.7 }}
              viewport={{ once: true }}
            >
              <h2 className="font-heading text-3xl md:text-4xl font-bold mb-6">Stay updated with our latest insights</h2>
              <p className="text-white/80 text-lg mb-8 max-w-md">
                Join our newsletter to receive news, updates, and design inspiration right to your inbox.
              </p>
              
              <form className="flex flex-col sm:flex-row space-y-4 sm:space-y-0 max-w-md">
                <Input 
                  type="email" 
                  placeholder="Your email address" 
                  className="bg-white/10 border-0 focus:ring-white rounded-l-lg rounded-r-lg sm:rounded-r-none px-4 py-6 text-white placeholder:text-white/60"
                />
                <Button 
                  type="submit" 
                  className="bg-white text-blue-600 hover:bg-white/90 rounded-l-lg sm:rounded-l-none rounded-r-lg px-6 py-6 font-bold"
                >
                  Subscribe
                </Button>
              </form>
            </motion.div>
            
            <motion.div
              className="flex justify-end"
              initial={{ opacity: 0, y: 30 }}
              whileInView={{ opacity: 1, y: 0 }}
              transition={{ duration: 0.7, delay: 0.2 }}
              viewport={{ once: true }}
            >
              <div className="space-y-6 max-w-sm">
                <h3 className="font-heading text-2xl font-bold mb-6">Our Global Offices</h3>
                <div className="space-y-4">
                  {locations.map((location, index) => (
                    <motion.div 
                      key={location.city}
                      initial={{ opacity: 0, x: 20 }}
                      whileInView={{ opacity: 1, x: 0 }}
                      transition={{ duration: 0.5, delay: 0.2 + (index * 0.1) }}
                      viewport={{ once: true }}
                    >
                      <LocationItem 
                        city={location.city} 
                        country={location.country} 
                        icon={location.icon} 
                      />
                    </motion.div>
                  ))}
                </div>
              </div>
            </motion.div>
          </div>
        </div>
      </div>
      
      {/* Main footer with links */}
      <div className="bg-black text-white py-16">
        <div className="container mx-auto px-6">
          <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-12 gap-10 mb-16">
            <motion.div 
              className="lg:col-span-4"
              initial={{ opacity: 0, y: 20 }}
              whileInView={{ opacity: 1, y: 0 }}
              transition={{ duration: 0.5 }}
              viewport={{ once: true }}
            >
              <Link href="/" className="font-heading font-bold text-3xl mb-6 inline-block">
                Burla<span className="text-blue-500">tech</span>
              </Link>
              <p className="text-white/70 mb-8 max-w-md">
                A multidisciplinary agency providing strategy, innovation, branding, and design services for ambitious businesses.
              </p>
              <div className="flex space-x-4">
                {socialLinks.map((link, index) => (
                  <SocialIcon 
                    key={index}
                    icon={link.icon}
                    href={link.href}
                    color={link.color}
                  />
                ))}
              </div>
            </motion.div>
            
            <div className="lg:col-span-8">
              <div className="grid grid-cols-1 sm:grid-cols-2 lg:grid-cols-3 gap-10">
                <FooterLinkGroup title="Services" links={servicesLinks} delay={0.1} />
                <FooterLinkGroup title="Company" links={companyLinks} delay={0.2} />
                
                <motion.div
                  initial={{ opacity: 0, y: 20 }}
                  whileInView={{ opacity: 1, y: 0 }}
                  transition={{ duration: 0.5, delay: 0.3 }}
                  viewport={{ once: true }}
                >
                  <h3 className="font-heading font-bold text-xl mb-6">Get in Touch</h3>
                  <ul className="space-y-4">
                    <li className="flex items-start">
                      <Mail className="h-5 w-5 mr-3 mt-1 text-blue-500" />
                      <span>hello@burlatech.com</span>
                    </li>
                    <li className="flex items-start">
                      <Phone className="h-5 w-5 mr-3 mt-1 text-blue-500" />
                      <span>+1 (555) 234-5678</span>
                    </li>
                  </ul>
                </motion.div>
              </div>
            </div>
          </div>
          
          <motion.div 
            className="border-t border-white/10 pt-8 flex flex-col md:flex-row justify-between items-center"
            initial={{ opacity: 0 }}
            whileInView={{ opacity: 1 }}
            transition={{ duration: 0.5, delay: 0.4 }}
            viewport={{ once: true }}
          >
            <p className="text-white/50 mb-4 md:mb-0">© {currentYear} Burlatech. All rights reserved.</p>
            <div className="flex flex-wrap justify-center space-x-6">
              {footerLinks.map((link) => (
                <Link 
                  key={link.label} 
                  href={link.href} 
                  className="text-white/50 hover:text-white/80 transition-colors"
                >
                  {link.label}
                </Link>
              ))}
            </div>
          </motion.div>
        </div>
      </div>
    </footer>
  );
}
