import { useState, useEffect, useRef } from "react";
import { Button } from "@/components/ui/button";
import { motion, useScroll, useTransform, AnimatePresence } from "framer-motion";

export default function Hero() {
  const heroRef = useRef<HTMLElement>(null);
  const [mousePosition, setMousePosition] = useState({ x: 0, y: 0 });
  const [currentWordIndex, setCurrentWordIndex] = useState(0);
  
  // Words that will animate in sequence
  const roleWords = [
    "researchers",
    "strategists",
    "brand crafters",
    "digital creators",
    "product innovators"
  ];
  
  // Colors for the animated dots
  const dotColors = [
    "bg-blue-400",
    "bg-pink-400",
    "bg-purple-400",
    "bg-yellow-400",
    "bg-green-400",
    "bg-red-400",
  ];
  
  // Change word every few seconds
  useEffect(() => {
    const interval = setInterval(() => {
      setCurrentWordIndex((prevIndex) => (prevIndex + 1) % roleWords.length);
    }, 3000); // Slower rotation for better readability
    
    return () => clearInterval(interval);
  }, []);
  
  // Parallax effect for mouse movement
  const handleMouseMove = (e: React.MouseEvent<HTMLElement>) => {
    if (!heroRef.current) return;
    
    const { clientX, clientY } = e;
    const { width, height, left, top } = heroRef.current.getBoundingClientRect();
    
    // Calculate mouse position relative to the center of the hero section
    const x = (clientX - left - width / 2) / 25;
    const y = (clientY - top - height / 2) / 25;
    
    setMousePosition({ x, y });
  };
  
  // Scroll animation
  const { scrollYProgress } = useScroll({
    target: heroRef,
    offset: ["start start", "end start"]
  });
  
  const opacity = useTransform(scrollYProgress, [0, 0.5], [1, 0]);
  const y = useTransform(scrollYProgress, [0, 0.5], [0, 100]);
  
  // Background animation variants
  const backgroundVariants = {
    animate: {
      backgroundPosition: ['0% 0%', '100% 100%'],
      transition: {
        duration: 20,
        ease: "linear",
        repeat: Infinity,
        repeatType: "reverse" as const
      }
    }
  };
  
  // Animated dot for background
  const AnimatedDot = ({ delay, size, color, left, top, blur }: 
    { delay: number, size: number, color: string, left: string, top: string, blur: number }) => {
    return (
      <motion.div 
        className={`absolute rounded-full ${color}`}
        style={{ 
          width: size, 
          height: size, 
          left, 
          top, 
          filter: `blur(${blur}px)`,
          opacity: 0.6,
        }}
        animate={{
          y: [0, -20, 0, 20, 0],
          x: [0, 20, 0, -20, 0],
          scale: [1, 1.1, 1, 0.9, 1],
        }}
        transition={{
          duration: 10,
          ease: "linear",
          times: [0, 0.25, 0.5, 0.75, 1],
          repeat: Infinity,
          delay: delay
        }}
      />
    );
  };
  
  return (
    <motion.section 
      ref={heroRef} 
      className="min-h-[90vh] pt-16 relative overflow-hidden flex items-center" 
      onMouseMove={handleMouseMove}
      style={{
        background: 'linear-gradient(135deg, #00C9A7 0%, #17CAD9 50%, #4F55FD 100%)',
        backgroundSize: '200% 200%',
      }}
      variants={backgroundVariants}
      animate="animate"
    >
      {/* Animated background dots */}
      <AnimatedDot delay={0} size={300} color="bg-blue-500/20" left="10%" top="20%" blur={70} />
      <AnimatedDot delay={1} size={200} color="bg-teal-500/20" left="70%" top="60%" blur={60} />
      <AnimatedDot delay={2} size={150} color="bg-purple-500/20" left="80%" top="10%" blur={50} />
      <AnimatedDot delay={3} size={250} color="bg-indigo-500/20" left="20%" top="70%" blur={65} />
      <AnimatedDot delay={4} size={180} color="bg-cyan-500/20" left="50%" top="40%" blur={55} />
      
      {/* Interactive background shapes that follow mouse */}
      <motion.div 
        className="absolute w-[500px] h-[500px] bg-gradient-to-r from-blue-400/20 to-cyan-400/20 rounded-full filter blur-[80px] mix-blend-overlay"
        style={{
          x: mousePosition.x * -3,
          y: mousePosition.y * -3,
          top: '30%',
          left: '50%',
          translateX: '-50%',
        }}
      />
      <motion.div 
        className="absolute w-[300px] h-[300px] bg-gradient-to-r from-purple-400/20 to-pink-400/20 rounded-full filter blur-[60px] mix-blend-overlay"
        style={{
          x: mousePosition.x * 3,
          y: mousePosition.y * 3,
          top: '60%',
          left: '30%',
        }}
      />
      
      <motion.div 
        style={{ opacity, y }} 
        className="container mx-auto px-6 relative z-10 py-10 md:py-16"
      >
        <div className="flex flex-col items-center text-center text-white">
          <motion.span 
            className="inline-block font-heading font-bold px-4 py-2 border border-white/20 rounded-full backdrop-blur-sm mb-8 bg-yellow-300 text-black"
            initial={{ opacity: 0, y: 20 }}
            animate={{ opacity: 1, y: 0, scale: [1, 1.05, 1] }}
            transition={{ delay: 0.2, duration: 1.2 }}
          >
            Collaborative Brand Builders
          </motion.span>
          
          <motion.h1 
            className="font-heading text-4xl md:text-5xl lg:text-7xl font-bold leading-tight mb-8 max-w-4xl"
            initial={{ opacity: 0, y: 30 }}
            animate={{ opacity: 1, y: 0 }}
            transition={{ delay: 0.4, duration: 0.8 }}
          >
            <span className="text-white">We are a team of</span>
            <div className="h-[1.2em] overflow-hidden relative inline-block w-full my-2">
              <AnimatePresence mode="wait">
                <motion.span
                  key={currentWordIndex}
                  className="absolute inset-0 flex items-center justify-center w-full text-center text-yellow-300"
                  initial={{ y: 20, opacity: 0 }}
                  animate={{ y: 0, opacity: 1 }}
                  exit={{ y: -20, opacity: 0 }}
                  transition={{ duration: 0.4, ease: "easeInOut" }}
                >
                  {roleWords[currentWordIndex]}
                </motion.span>
              </AnimatePresence>
            </div>
            <div className="text-white">
              <span>that </span>
              <span className="text-yellow-300 font-bold">work together</span>
              <span> to </span>
              <span className="text-white font-bold text-[1.2em]">generate </span>
              <span className="text-white">business-led </span>
              <span className="text-white font-bold text-[1.2em] animate-pulse-slow">design </span>
              <span className="text-white">solutions.</span>
            </div>
          </motion.h1>
          
          <motion.div
            initial={{ opacity: 0, y: 30 }}
            animate={{ opacity: 1, y: 0 }}
            transition={{ delay: 0.8 }}
            whileHover={{ scale: 1.05 }}
            whileTap={{ scale: 0.98 }}
          >
            <Button 
              size="lg" 
              className="bg-yellow-300 text-black hover:bg-yellow-400 rounded-full shadow-lg font-heading text-lg font-bold px-8 py-6"
              asChild
            >
              <a href="#about">About us</a>
            </Button>
          </motion.div>
        </div>
      </motion.div>
      
      {/* Abstract design elements */}
      <motion.div
        className="absolute top-0 left-0 w-full h-8 bg-yellow-300"
        initial={{ opacity: 0 }}
        animate={{ opacity: 1 }}
        transition={{ delay: 0.3 }}
      />
      <motion.div
        className="absolute -bottom-2 left-0 right-0 h-6 bg-white rounded-t-[30%] z-[5]"
        initial={{ opacity: 0, y: 20 }}
        animate={{ opacity: 1, y: 0 }}
        transition={{ delay: 0.5 }}
      />
      
      {/* Small animated circles */}
      {dotColors.map((color, index) => (
        <motion.div 
          key={index}
          className={`absolute ${color} rounded-full h-3 w-3`}
          initial={{ 
            x: Math.random() * 100 - 50, 
            y: Math.random() * 100 - 50,
            opacity: 0 
          }}
          animate={{ 
            x: Math.random() * 100 - 50, 
            y: Math.random() * 100 - 50, 
            opacity: [0, 1, 0]
          }}
          transition={{
            duration: 5 + Math.random() * 5,
            repeat: Infinity,
            delay: index * 0.5,
          }}
          style={{ 
            left: `${Math.random() * 80 + 10}%`,
            top: `${Math.random() * 80 + 10}%`,
          }}
        />
      ))}
    </motion.section>
  );
}
