import { useState, useEffect } from "react";
import { Link } from "wouter";
import { Menu, X } from "lucide-react";
import { Button } from "@/components/ui/button";
import { motion } from "framer-motion";

export default function Navbar() {
  const [isMenuOpen, setIsMenuOpen] = useState(false);
  // Using a consistent navbar style without floating functionality

  // Toggle mobile menu
  const toggleMenu = () => {
    setIsMenuOpen(!isMenuOpen);
    
    // Prevent scrolling when menu is open
    if (!isMenuOpen) {
      document.body.style.overflow = "hidden";
    } else {
      document.body.style.overflow = "";
    }
  };

  // Close menu
  const closeMenu = () => {
    setIsMenuOpen(false);
    document.body.style.overflow = "";
  };

  // Navigation items
  const navItems = [
    { label: "Services", href: "#services" },
    { label: "About", href: "#about" },
    { label: "Our Work", href: "#work" },
    { label: "Contact", href: "#contact" }
  ];

  return (
    <>
      {/* Yellow top bar */}
      <div className="fixed top-0 left-0 right-0 h-8 bg-yellow-300 z-50"></div>
      
      <motion.header 
        className="fixed top-8 left-0 right-0 z-50 bg-white shadow-sm py-4"
        initial={{ opacity: 0, y: -20 }}
        animate={{ opacity: 1, y: 0 }}
        transition={{ duration: 0.5 }}
      >
        <nav className="container mx-auto px-6 flex justify-between items-center">
          <Link href="/" className="font-heading font-bold text-3xl relative z-10">
            Burla<span className="text-yellow-300">tech</span>
          </Link>
          
          {/* Desktop menu */}
          <div className="hidden md:flex items-center space-x-2">
            {navItems.map((item, index) => (
              index === navItems.length - 1 ? (
                <motion.div
                  key={item.label}
                  whileHover={{ scale: 1.05 }}
                  whileTap={{ scale: 0.98 }}
                >
                  <Button 
                    className="bg-yellow-300 text-black hover:bg-yellow-400 rounded-full px-6 py-5 font-heading text-base font-bold"
                    asChild
                  >
                    <a href={item.href}>{item.label}</a>
                  </Button>
                </motion.div>
              ) : (
                <motion.div
                  key={item.label}
                  whileHover={{ y: -2 }}
                  whileTap={{ y: 0 }}
                  className="px-4"
                >
                  <a 
                    href={item.href} 
                    className="font-heading font-medium text-base hover:text-yellow-300 transition-colors relative group"
                  >
                    {item.label}
                    <span className="absolute -bottom-1 left-0 w-0 h-0.5 bg-yellow-300 transition-all group-hover:w-full"></span>
                  </a>
                </motion.div>
              )
            ))}
          </div>
          
          {/* Mobile menu toggle */}
          <Button 
            variant="ghost" 
            size="icon" 
            className="md:hidden text-black" 
            onClick={toggleMenu}
            aria-label="Toggle menu"
          >
            <Menu className="h-6 w-6" />
          </Button>
        </nav>
      </motion.header>
      
      {/* Mobile navigation menu */}
      <div className={`fixed top-0 right-0 h-full w-4/5 bg-gradient-to-br from-cyan-500 to-blue-600 text-white z-[60] shadow-xl flex flex-col p-8 transform transition-transform duration-300 ease-in-out md:hidden ${isMenuOpen ? "translate-x-0" : "translate-x-full"}`}>
        <div className="flex justify-end mb-8">
          <Button 
            variant="ghost" 
            size="icon" 
            className="text-white" 
            onClick={closeMenu}
            aria-label="Close menu"
          >
            <X className="h-6 w-6" />
          </Button>
        </div>
        
        <div className="flex flex-col space-y-6 text-xl font-heading">
          {navItems.map((item, index) => (
            index === navItems.length - 1 ? (
              <Button 
                key={item.label} 
                className="mt-4 bg-yellow-300 text-black hover:bg-yellow-400 rounded-full w-full font-heading font-bold py-6"
                asChild
                onClick={closeMenu}
              >
                <a href={item.href}>{item.label}</a>
              </Button>
            ) : (
              <a 
                key={item.label} 
                href={item.href} 
                className="pb-2 border-b border-white/20 font-medium"
                onClick={closeMenu}
              >
                {item.label}
              </a>
            )
          ))}
        </div>
      </div>
      
      {/* Overlay for mobile menu */}
      {isMenuOpen && (
        <div 
          className="fixed inset-0 bg-black/50 z-50 md:hidden" 
          onClick={closeMenu}
          aria-hidden="true"
        />
      )}
    </>
  );
}
