import { useRef } from "react";
import { 
  Lightbulb, 
  Paintbrush, 
  Globe, 
  Boxes, 
  MessageSquare, 
  Package, 
  ArrowRight
} from "lucide-react";
import { motion, useInView } from "framer-motion";

// Service card interface
interface ServiceCardProps {
  icon: React.ReactNode;
  title: string;
  description: string;
  index: number;
  color: string;
}

// Service Card component with subtle fade-in animation similar to location cards
const ServiceCard = ({ icon, title, description, index, color }: ServiceCardProps) => {  
  return (
    <motion.div 
      className="service-card relative rounded-2xl overflow-hidden h-[350px] md:h-[400px]"
      style={{ backgroundColor: color }}
      // No fade-in animation, just hover effect
      whileHover={{ 
        y: -10,
        transition: { duration: 0.3 }
      }}
    >
      <div className="absolute inset-0 p-8 flex flex-col justify-between h-full text-white">
        {/* Top part with all content */}
        <div>
          {/* Service icon - no animation */}
          <div className="text-white text-4xl mb-6">
            {icon}
          </div>
          
          {/* Content - no animations */}
          <h3 className="font-heading text-2xl font-bold mb-3 text-white">
            {title}
          </h3>
          
          <p className="text-white/90 text-lg">
            {description}
          </p>
        </div>
        
        {/* Bottom part with arrow - only hover animation */}
        <div className="flex items-center justify-between font-medium text-white mt-4">
          <span className="font-bold">Learn more</span>
          <motion.div 
            className="h-12 w-12 rounded-full bg-white/20 flex items-center justify-center transition-all duration-300"
            whileHover={{ 
              scale: 1.1, 
              backgroundColor: "rgba(255, 255, 255, 0.3)" 
            }}
          >
            <ArrowRight className="h-5 w-5 text-white" />
          </motion.div>
        </div>
      </div>
      
      {/* Background pattern */}
      <div className="absolute right-0 bottom-0 w-32 h-32 rounded-tl-full bg-white/5" />
      <div className="absolute left-0 top-0 w-16 h-16 rounded-br-full bg-white/5" />
    </motion.div>
  );
};

export default function Services() {
  const sectionRef = useRef<HTMLDivElement>(null);
  
  // Service data with vibrant colors
  const services = [
    {
      icon: <Lightbulb className="h-10 w-10" />,
      title: "Strategy & Innovation",
      description: "Forward-thinking approaches to solve complex business challenges and identify growth opportunities.",
      color: "#4F55FD" // Bright blue
    },
    {
      icon: <Paintbrush className="h-10 w-10" />,
      title: "Branding Design",
      description: "Comprehensive brand identity development to create memorable and compelling brand experiences.",
      color: "#00C9A7" // Teal
    },
    {
      icon: <Globe className="h-10 w-10" />,
      title: "Digital Design",
      description: "User-centered websites and digital products that deliver exceptional experiences across all devices.",
      color: "#FF5470" // Pink
    },
    {
      icon: <Boxes className="h-10 w-10" />,
      title: "Product Design",
      description: "Innovative physical and digital product development from concept to market-ready solutions.",
      color: "#FFC043" // Yellow/Orange
    },
    {
      icon: <MessageSquare className="h-10 w-10" />,
      title: "Communication Services",
      description: "Strategic communication plans and content creation to effectively engage with your target audience.",
      color: "#6A3DE8" // Purple
    },
    {
      icon: <Package className="h-10 w-10" />,
      title: "Packaging Design",
      description: "Eye-catching packaging solutions that enhance product perception and create shelf impact.",
      color: "#FF7E36" // Orange
    }
  ];

  return (
    <section id="services" className="py-20 md:py-0 relative overflow-hidden">
      <div className="w-full h-8 bg-yellow-300"></div>
      <motion.div
        className="absolute top-8 left-0 w-full h-16 bg-blue-600"
        initial={{ opacity: 0 }}
        whileInView={{ opacity: 1 }}
        transition={{ duration: 0.5 }}
        viewport={{ once: true }}
      />
      
      <div className="relative z-10" ref={sectionRef}>
        <div className="container mx-auto px-6 py-20">
          <motion.div 
            className="max-w-3xl mx-auto mb-16"
            initial={{ opacity: 0, y: 30 }}
            whileInView={{ opacity: 1, y: 0 }}
            transition={{ duration: 0.7 }}
            viewport={{ once: true, amount: 0.2 }}
          >
            <div className="flex flex-col md:flex-row justify-between md:items-end">
              <div>
                <motion.span 
                  className="text-blue-600 font-bold inline-block mb-2 text-lg"
                  initial={{ opacity: 0, x: -20 }}
                  whileInView={{ opacity: 1, x: 0 }}
                  transition={{ duration: 0.5, delay: 0.2 }}
                  viewport={{ once: true }}
                >
                  What We Do
                </motion.span>
                <motion.h2 
                  className="font-heading text-4xl md:text-5xl font-bold mb-2"
                  initial={{ opacity: 0, y: 20 }}
                  whileInView={{ opacity: 1, y: 0 }}
                  transition={{ duration: 0.5, delay: 0.3 }}
                  viewport={{ once: true }}
                >
                  A Full Spectrum of<br />
                  Design Services
                </motion.h2>
              </div>
              <motion.p 
                className="text-lg text-gray-600 md:text-xl md:max-w-md mt-4 md:mt-0"
                initial={{ opacity: 0, y: 20 }}
                whileInView={{ opacity: 1, y: 0 }}
                transition={{ duration: 0.5, delay: 0.4 }}
                viewport={{ once: true }}
              >
                We combine strategy, design, and technology to create experiences that drive business growth and connect with your audience.
              </motion.p>
            </div>
          </motion.div>
          
          {/* Services Grid */}
          <motion.div 
            className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-6 lg:gap-8"
            initial={{ opacity: 0, y: 20 }}
            whileInView={{ opacity: 1, y: 0 }}
            transition={{ duration: 0.8 }}
            viewport={{ once: true, amount: 0.1 }}
          >
            {services.map((service, index) => (
              <ServiceCard 
                key={service.title}
                icon={service.icon}
                title={service.title}
                description={service.description}
                index={index}
                color={service.color}
              />
            ))}
          </motion.div>
        </div>
      </div>
    </section>
  );
}
