import { Button } from "@/components/ui/button";
import { motion, useInView } from "framer-motion";
import { useState, useRef } from "react";
import { ArrowRight } from "lucide-react";

// Project card interface
interface ProjectCardProps {
  image: string;
  logo: string;
  category: string;
  title: string;
  index: number;
  color: string;
}

// Project Card component with modern animated design
const ProjectCard = ({ image, logo, category, title, index, color }: ProjectCardProps) => {
  const cardRef = useRef<HTMLDivElement>(null);
  const isInView = useInView(cardRef, { once: true, amount: 0.2 });
  
  return (
    <motion.div
      ref={cardRef}
      className="group relative overflow-hidden rounded-2xl"
      initial={{ opacity: 0, y: 50 }}
      animate={isInView ? { opacity: 1, y: 0 } : { opacity: 0, y: 50 }}
      transition={{ 
        duration: 0.6, 
        delay: index * 0.1,
        ease: [0.22, 1, 0.36, 1]
      }}
      whileHover={{ 
        y: -10,
        transition: { duration: 0.3 }
      }}
    >
      <div className="flex flex-col h-full">
        {/* Project image with overlay */}
        <div className="relative overflow-hidden">
          <div 
            className="aspect-[4/3] bg-cover bg-center" 
            style={{ backgroundImage: `url(${image})` }}
          />
          <div 
            className="absolute inset-0 opacity-30 md:opacity-0 group-hover:opacity-80 transition-opacity duration-300" 
            style={{ backgroundColor: color }}
          />
          <motion.div 
            className="absolute inset-0 p-8 text-white flex flex-col justify-between opacity-100 md:opacity-100 transition-opacity duration-300"
            initial={{ y: 0 }}
            whileHover={{ y: 0 }}
            transition={{ duration: 0.3 }}
          >
            <div>
              <p className="text-sm uppercase tracking-wider font-medium mb-1">{category}</p>
              <h3 className="font-heading text-2xl font-bold">{title}</h3>
            </div>
            <motion.div 
              className="h-12 w-12 rounded-full bg-white/20 flex items-center justify-center"
              whileHover={{ 
                scale: 1.1, 
                backgroundColor: "rgba(255, 255, 255, 0.3)" 
              }}
            >
              <ArrowRight className="h-5 w-5 text-white" />
            </motion.div>
          </motion.div>
        </div>
        
        {/* Company logo */}
        <div className="bg-white p-6 flex justify-center items-center min-h-[80px]">
          <img src={logo} alt={`${title} logo`} className="h-10" />
        </div>
      </div>
    </motion.div>
  );
};

// Project filter component
const ProjectFilter = ({ 
  categories, 
  activeCategory, 
  setActiveCategory 
}: { 
  categories: string[], 
  activeCategory: string, 
  setActiveCategory: (category: string) => void 
}) => {
  return (
    <div className="flex flex-wrap gap-4 mb-12">
      {categories.map(category => (
        <motion.button
          key={category}
          className={`px-6 py-2 rounded-full text-sm font-medium transition-colors ${activeCategory === category ? 'bg-black text-white' : 'bg-gray-100 text-gray-700 hover:bg-gray-200'}`}
          onClick={() => setActiveCategory(category)}
          whileHover={{ scale: 1.05 }}
          whileTap={{ scale: 0.98 }}
        >
          {category}
        </motion.button>
      ))}
    </div>
  );
};

export default function Work() {
  // Categories for filtering
  const categories = ["All", "Branding", "Digital", "Product", "Packaging", "UX/UI"];
  const [activeCategory, setActiveCategory] = useState("All");
  
  // Projects data with more details
  const projects = [
    {
      image: "https://images.unsplash.com/photo-1558655146-d09347e92766?ixlib=rb-4.0.3&auto=format&fit=crop&w=764&q=80",
      logo: "https://placehold.co/200x60/000000/FFFFFF/png?text=FINTECH",
      category: "Digital",
      title: "Fintech Mobile App",
      color: "#4F55FD"
    },
    {
      image: "https://images.unsplash.com/photo-1547658719-da2b51169166?ixlib=rb-4.0.3&auto=format&fit=crop&w=764&q=80",
      logo: "https://placehold.co/200x60/000000/FFFFFF/png?text=ECO+PACK",
      category: "Packaging",
      title: "Eco-Friendly Packaging",
      color: "#00C9A7"
    },
    {
      image: "https://images.unsplash.com/photo-1581291518633-83b4ebd1d83e?ixlib=rb-4.0.3&auto=format&fit=crop&w=870&q=80",
      logo: "https://placehold.co/200x60/000000/FFFFFF/png?text=SHOPIFY",
      category: "Digital",
      title: "E-commerce Platform",
      color: "#FF5470"
    },
    {
      image: "https://images.unsplash.com/photo-1618761714954-0b8cd0026356?ixlib=rb-4.0.3&auto=format&fit=crop&w=870&q=80",
      logo: "https://placehold.co/200x60/000000/FFFFFF/png?text=SMART+HOME",
      category: "Product",
      title: "Smart Home Device",
      color: "#FFC043"
    },
    {
      image: "https://images.unsplash.com/photo-1468436139062-f60a71c5c892?ixlib=rb-4.0.3&auto=format&fit=crop&w=870&q=80",
      logo: "https://placehold.co/200x60/000000/FFFFFF/png?text=SAAS+PRO",
      category: "UX/UI",
      title: "SaaS Dashboard",
      color: "#6A3DE8"
    },
    {
      image: "https://images.unsplash.com/photo-1635405074683-96d6921a2a68?ixlib=rb-4.0.3&auto=format&fit=crop&w=869&q=80",
      logo: "https://placehold.co/200x60/000000/FFFFFF/png?text=BISTRO",
      category: "Branding",
      title: "Restaurant Rebrand",
      color: "#FF7E36"
    }
  ];

  // Filter projects by category
  const filteredProjects = activeCategory === "All" 
    ? projects 
    : projects.filter(project => project.category === activeCategory);

  return (
    <section id="work" className="pt-0 pb-28 bg-gray-50">
      <div className="container mx-auto px-6">
        <motion.div 
          className="mb-16"
          initial={{ opacity: 0, y: 30 }}
          whileInView={{ opacity: 1, y: 0 }}
          transition={{ duration: 0.7 }}
          viewport={{ once: true }}
        >
          <div className="flex flex-col md:flex-row justify-between md:items-end">
            <div>
              <motion.span 
                className="text-blue-600 font-bold inline-block mb-2 text-lg"
                initial={{ opacity: 0, x: -20 }}
                whileInView={{ opacity: 1, x: 0 }}
                transition={{ duration: 0.5 }}
                viewport={{ once: true }}
              >
                Case Studies
              </motion.span>
              <motion.h2 
                className="font-heading text-4xl md:text-5xl font-bold mb-2"
                initial={{ opacity: 0, y: 20 }}
                whileInView={{ opacity: 1, y: 0 }}
                transition={{ duration: 0.5, delay: 0.1 }}
                viewport={{ once: true }}
              >
                Glimpses of <br/>Brand Success
              </motion.h2>
            </div>
            <motion.p 
              className="text-lg text-gray-600 md:text-xl md:max-w-md mt-4 md:mt-0"
              initial={{ opacity: 0, y: 20 }}
              whileInView={{ opacity: 1, y: 0 }}
              transition={{ duration: 0.5, delay: 0.2 }}
              viewport={{ once: true }}
            >
              Explore some of our award-winning projects that deliver measurable results for our clients.
            </motion.p>
          </div>
        </motion.div>
        
        {/* Filters */}
        <motion.div 
          initial={{ opacity: 0, y: 20 }}
          whileInView={{ opacity: 1, y: 0 }}
          transition={{ duration: 0.5, delay: 0.3 }}
          viewport={{ once: true }}
        >
          <ProjectFilter 
            categories={categories} 
            activeCategory={activeCategory}
            setActiveCategory={setActiveCategory}
          />
        </motion.div>
        
        {/* Work Grid */}
        <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-8">
          {filteredProjects.map((project, index) => (
            <ProjectCard 
              key={project.title}
              image={project.image}
              logo={project.logo}
              category={project.category}
              title={project.title}
              index={index}
              color={project.color}
            />
          ))}
        </div>
        
        <motion.div 
          className="text-center mt-16"
          initial={{ opacity: 0, y: 20 }}
          whileInView={{ opacity: 1, y: 0 }}
          transition={{ duration: 0.5, delay: 0.4 }}
          viewport={{ once: true }}
        >
          <Button 
            variant="default" 
            size="lg" 
            className="bg-black hover:bg-black/90 text-white rounded-full px-8"
          >
            View All Projects
          </Button>
        </motion.div>
      </div>
    </section>
  );
}
